Module allowing the user to grade, check, and calibrate tests.

grading_server(id, test, tree, course_data, course_paths)

Arguments

id

Character. ID of the module to connect the user interface to the appropriate server side.

test

Reactive. Selected test.

tree

Reactive. Function containing a list of documents as a classification tree compatible with jsTreeR.

course_data

Reactive. Function containing all the course data loaded with the course.

course_paths

Reactive. Function containing a list of paths to the different folders and databases on local disk.

Value

Save the test results in the relevant test sub-folder.

Author

Nicolas Mangin