Module allowing the user to grade, check, and calibrate tests.

grading_ui(id)

Arguments

id

Character. ID of the module to connect the user interface to the appropriate server side.

Value

Save the test results in the relevant test sub-folder.

Author

Nicolas Mangin