Function creating the user interface to grade an item.

make_scale(letter, proposition, scale, checked, correct, ns)

Arguments

letter

Character. Letter in the propositions database.

proposition

Character. Answer/criterion selected or given.

scale

Character. Whether the initial scale of the letter is "logical", "numeric", a "percentage", or "qualitative".

checked

Integer. 1 if the student provided this answer, 0 otherwise.

correct

Numeric. Whether the answer is correct.

ns

Function. Function assigning input IDs to the relevant module.

Value

A shiny user interface for checking or grading answers.

Author

Nicolas Mangin