Function computing new weights for items of each question based on test parameters.

reinitialize_weights(test_parameters, feedbacks, selected_question = NULL)

Arguments

test_parameters

Tibble. Test parameters.

feedbacks

Tibble. Local feedback files combined.

selected_question

Character. Question file if one question in particular is targeted.

Value

Feedback with updated weights

Author

Nicolas Mangin