grading_server.RdModule allowing the user to grade, check, and calibrate tests.
grading_server(id, test, tree, course_data, course_paths)Character. ID of the module to connect the user interface to the appropriate server side.
Reactive. Selected test.
Reactive. Function containing a list of documents as a classification tree compatible with jsTreeR.
Reactive. Function containing all the course data loaded with the course.
Reactive. Function containing a list of paths to the different folders and databases on local disk.
Save the test results in the relevant test sub-folder.