make_scale.RdFunction creating the user interface to grade an item.
make_scale(letter, proposition, scale, checked, correct, ns)Character. Letter in the propositions database.
Character. Answer/criterion selected or given.
Character. Whether the initial scale of the letter is "logical", "numeric", a "percentage", or "qualitative".
Integer. 1 if the student provided this answer, 0 otherwise.
Numeric. Whether the answer is correct.
Function. Function assigning input IDs to the relevant module.
A shiny user interface for checking or grading answers.